@@ -53,10 +53,12 @@ typedef uint128_t uint128_t_a8 __attribute__ ((aligned(8)));
 typedef enum {
     MMDBW_SUCCESS,
     MMDBW_FINDING_NODE_ERROR,
+    MMDBW_INSERT_INTO_ALIAS_NODE_ERROR,
     MMDBW_FREED_ALIAS_NODE_ERROR,
     MMDBW_FREED_FIXED_NODE_ERROR,
     MMDBW_ALIAS_OVERWRITE_ATTEMPT_ERROR,
-    MMDBW_INSERT_FIXED_NODE_RECORD_ERROR,
+    MMDBW_FIXED_NODE_OVERWRITE_ATTEMPT_ERROR,
+    MMDBW_RESOLVING_IP_ERROR,
 } MMDBW_status;
 
 typedef enum {
@@ -162,7 +164,6 @@ typedef void (MMDBW_iterator_callback)(MMDBW_tree_s *tree,
     extern SV *data_for_key(MMDBW_tree_s *tree, const char *const key);
     extern void free_tree(MMDBW_tree_s *tree);
     extern void free_merge_cache(MMDBW_tree_s *tree);
-    extern const char *record_type_name(int record_type);
     extern void warn_hex(uint8_t digest[16], char *where);
     extern char *md5_as_hex(uint8_t digest[16]);
     /* --prototypes end - don't remove this comment-- */
